@@ -2,18 +2,16 @@
 # this repository contains the full copyright notices and license terms.
 
 from trytond.pool import Pool
-from . import stock
-from . import sale
-from . import purchase
-from . import party
+
+from . import party, product, purchase, sale, stock
 
 
 def register():
     Pool.register(
         stock.Configuration,
         stock.ConfigurationSequence,
-        stock.ShipmentDrop,
         stock.Move,
+        stock.ShipmentDrop,
         sale.Configuration,
         sale.ConfigurationSaleDropLocation,
         sale.Sale,
@@ -24,6 +22,7 @@ def register():
         purchase.Purchase,
         purchase.Line,
         purchase.ProductSupplier,
+        product.Product,
         module='sale_supply_drop_shipment', type_='model')
     Pool.register(
         purchase.RequestCreatePurchase,
